class Task(object):
    """docstring for Task"""
    def __init__(self, task_name, task, analysis):
        super().__init__()
        self.task_name = task_name
        self.input_files = []
        self.output_files = []
        self.inputs = task['inputs']
        self.outputs = task['outputs']
        self.docker_image = task.get('dockerImageUsed', None)
        self.analysis = analysis



import argparse
from accession.accession import Accession
from accession.helpers import filter_outputs_by_path


def get_parser():
    parser = argparse.ArgumentParser(description="Accession pipeline outputs, \
                                                 download output metadata for scattering")
    parser.add_argument('--filter-from-path',
                        type=str,
                        default=None,
                        help='path to a folder with pipeline run outputs')
    parser.add_argument('--accession-metadata',
                        type=str,
                        default=None,
                        help='path to a metadata json output file')
    parser.add_argument('--accession-steps',
                        type=str,
                        default=None,
                        help='path to an accessioning steps, json file')
    parser.add_argument('--server',
                        default='dev',
                        help='Server the files will be accessioned to')
    parser.add_argument('--lab',
                        type=str,
                        default=None,
                        help='Lab')
    parser.add_argument('--award',
                        type=str,
                        default=None,
                        help='Award')
    return parser


def main(args=None):
    parser = get_parser()
    args = parser.parse_args(args)

    if args.filter_from_path:
        filter_outputs_by_path(args.filter_from_path)
        return
    accession_steps = args.accession_steps
    accession_metadata = args.accession_metadata
    lab = args.lab
    award = args.award
    server = args.server
    if all([accession_steps,
            accession_metadata,
            lab,
            award,
            server]):
        accessioner = Accession(accession_steps,
                                accession_metadata,
                                server,
                                lab,
                                award)
        accessioner.accession_steps()
        return
    print("Module called without proper arguments")


if __name__ == '__main__':
    main()



class GSFile(object):
    """docstring for File"""
    def __init__(self, key, name, md5sum, size, task=None, used_by_tasks=None):
        super().__init__()
        self.filename = name
        self.filekeys = [key]
        self.task = task
        self.used_by_tasks = [used_by_tasks] if used_by_tasks else []
        self.md5sum = md5sum
        self.size = size